/*
 * --------------------------------------------------------------------------------------------------------------------
 * <copyright company="Aspose">
 *   Copyright (c) 2018 Aspose.Slides for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------------------------------------------
 */

package com.aspose.slides.model;

import java.util.Objects;
import com.aspose.slides.model.EffectFormat;
import com.aspose.slides.model.FillFormat;
import com.aspose.slides.model.GeometryShape;
import com.aspose.slides.model.Hyperlink;
import com.aspose.slides.model.LineFormat;
import com.aspose.slides.model.ResourceUri;
import com.aspose.slides.model.TextFrameFormat;
import com.aspose.slides.model.ThreeDFormat;
import com.google.gson.TypeAdapter;
import com.google.gson.annotations.JsonAdapter;
import com.google.gson.annotations.SerializedName;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.IOException;
import java.util.List;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Map;

/**
 * Represents AutoShape resource.
 */
@ApiModel(description = "Represents AutoShape resource.")
public class Shape extends GeometryShape {
  @SerializedName(value = "text", alternate = { "Text" })
  private String text;

  @SerializedName(value = "paragraphs", alternate = { "Paragraphs" })
  private ResourceUri paragraphs;

  @SerializedName(value = "textFrameFormat", alternate = { "TextFrameFormat" })
  private TextFrameFormat textFrameFormat;


  public Shape() {
    super();
    setType(TypeEnum.SHAPE);
  }

  public Shape text(String text) {
    this.text = text;
    return this;
  }

   /**
   * Gets or sets the text.
   * @return text
  **/
  @ApiModelProperty(value = "Gets or sets the text.")
  public String getText() {
    return text;
  }

  public void setText(String text) {
    this.text = text;
  }

  public Shape paragraphs(ResourceUri paragraphs) {
    this.paragraphs = paragraphs;
    return this;
  }

   /**
   * Get or sets list to paragraphs list
   * @return paragraphs
  **/
  @ApiModelProperty(value = "Get or sets list to paragraphs list")
  public ResourceUri getParagraphs() {
    return paragraphs;
  }

  public void setParagraphs(ResourceUri paragraphs) {
    this.paragraphs = paragraphs;
  }

  public Shape textFrameFormat(TextFrameFormat textFrameFormat) {
    this.textFrameFormat = textFrameFormat;
    return this;
  }

   /**
   * Returns TextFrame&#39;s formatting properties.
   * @return textFrameFormat
  **/
  @ApiModelProperty(value = "Returns TextFrame's formatting properties.")
  public TextFrameFormat getTextFrameFormat() {
    return textFrameFormat;
  }

  public void setTextFrameFormat(TextFrameFormat textFrameFormat) {
    this.textFrameFormat = textFrameFormat;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Shape shape = (Shape) o;
    return true && Objects.equals(this.text, shape.text) && Objects.equals(this.paragraphs, shape.paragraphs) && Objects.equals(this.textFrameFormat, shape.textFrameFormat) && super.equals(o);
  }

  @Override
  public int hashCode() {
    return Objects.hash(text, paragraphs, textFrameFormat, super.hashCode());
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class Shape {\n");
    sb.append("    ").append(toIndentedString(super.toString())).append("\n");
    sb.append("    text: ").append(toIndentedString(text)).append("\n");
    sb.append("    paragraphs: ").append(toIndentedString(paragraphs)).append("\n");
    sb.append("    textFrameFormat: ").append(toIndentedString(textFrameFormat)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }



  private static final Map<String, Object> typeDeterminers = new Hashtable<String, Object>();

  static {
      typeDeterminers.put("Type", TypeEnum.SHAPE);
  }
}
